@@ -6,11 +6,7 @@ use base qw(App::CLI App::CLI::Command);
 
 use constant global_options => ( 'help' => 'help' );
 
-sub alias {
-    (
-        "all" => "cloneall"
-    );
-}
+sub alias { ( "all" => "cloneall" ) }
 
 sub invoke {
     my ($pkg, $cmd, @args) = @_;
